==> vtk6-6.3.0-4-aarch64.pkg.tar.xz: vtk/vtkCheckerboardRepresentation.java <==
// java wrapper for vtkCheckerboardRepresentation object
//

package vtk;
import vtk.*;

public class vtkCheckerboardRepresentation extends vtkWidgetRepresentation
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetCheckerboard_2(vtkImageCheckerboard id0);
  public void SetCheckerboard(vtkImageCheckerboard id0)
    { SetCheckerboard_2(id0); }

  private native long GetCheckerboard_3();
  public vtkImageCheckerboard GetCheckerboard() {
    long temp = GetCheckerboard_3();

    if (temp == 0) return null;
    return (vtkImageCheckerboard)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void SetImageActor_4(vtkImageActor id0);
  public void SetImageActor(vtkImageActor id0)
    { SetImageActor_4(id0); }

  private native long GetImageActor_5();
  public vtkImageActor GetImageActor() {
    long temp = GetImageActor_5();

    if (temp == 0) return null;
    return (vtkImageActor)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void SetCornerOffset_6(double id0);
  public void SetCornerOffset(double id0)
    { SetCornerOffset_6(id0); }

  private native double GetCornerOffsetMinValue_7();
  public double GetCornerOffsetMinValue()
    { return GetCornerOffsetMinValue_7(); }

  private native double GetCornerOffsetMaxValue_8();
  public double GetCornerOffsetMaxValue()
    { return GetCornerOffsetMaxValue_8(); }

  private native double GetCornerOffset_9();
  public double GetCornerOffset()
    { return GetCornerOffset_9(); }

  private native void SliderValueChanged_10(int id0);
  public void SliderValueChanged(int id0)
    { SliderValueChanged_10(id0); }

  private native void SetTopRepresentation_11(vtkSliderRepresentation3D id0);
  public void SetTopRepresentation(vtkSliderRepresentation3D id0)
    { SetTopRepresentation_11(id0); }

  private native void SetRightRepresentation_12(vtkSliderRepresentation3D id0);
  public void SetRightRepresentation(vtkSliderRepresentation3D id0)
    { SetRightRepresentation_12(id0); }

  private native void SetBottomRepresentation_13(vtkSliderRepresentation3D id0);
  public void SetBottomRepresentation(vtkSliderRepresentation3D id0)
    { SetBottomRepresentation_13(id0); }

  private native void SetLeftRepresentation_14(vtkSliderRepresentation3D id0);
  public void SetLeftRepresentation(vtkSliderRepresentation3D id0)
    { SetLeftRepresentation_14(id0); }

  private native long GetTopRepresentation_15();
  public vtkSliderRepresentation3D GetTopRepresentation() {
    long temp = GetTopRepresentation_15();

    if (temp == 0) return null;
    return (vtkSliderRepresentation3D)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native long GetRightRepresentation_16();
  public vtkSliderRepresentation3D GetRightRepresentation() {
    long temp = GetRightRepresentation_16();

    if (temp == 0) return null;
    return (vtkSliderRepresentation3D)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native long GetBottomRepresentation_17();
  public vtkSliderRepresentation3D GetBottomRepresentation() {
    long temp = GetBottomRepresentation_17();

    if (temp == 0) return null;
    return (vtkSliderRepresentation3D)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native long GetLeftRepresentation_18();
  public vtkSliderRepresentation3D GetLeftRepresentation() {
    long temp = GetLeftRepresentation_18();

    if (temp == 0) return null;
    return (vtkSliderRepresentation3D)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void BuildRepresentation_19();
  public void BuildRepresentation()
    { BuildRepresentation_19(); }

  private native void GetActors_20(vtkPropCollection id0);
  public void GetActors(vtkPropCollection id0)
    { GetActors_20(id0); }

  private native void ReleaseGraphicsResources_21(vtkWindow id0);
  public void ReleaseGraphicsResources(vtkWindow id0)
    { ReleaseGraphicsResources_21(id0); }

  private native int RenderOverlay_22(vtkViewport id0);
  public int RenderOverlay(vtkViewport id0)
    { return RenderOverlay_22(id0); }

  private native int RenderOpaqueGeometry_23(vtkViewport id0);
  public int RenderOpaqueGeometry(vtkViewport id0)
    { return RenderOpaqueGeometry_23(id0); }

  private native int RenderTranslucentPolygonalGeometry_24(vtkViewport id0);
  public int RenderTranslucentPolygonalGeometry(vtkViewport id0)
    { return RenderTranslucentPolygonalGeometry_24(id0); }

  private native int HasTranslucentPolygonalGeometry_25();
  public int HasTranslucentPolygonalGeometry()
    { return HasTranslucentPolygonalGeometry_25(); }

  public vtkCheckerboardRepresentation() { super(); }

  public vtkCheckerboardRepresentation(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-20-aarch64.pkg.tar.xz: vtk/vtkCheckerboardRepresentation.java <==
// java wrapper for vtkCheckerboardRepresentation object
//

package vtk;
import vtk.*;

public class vtkCheckerboardRepresentation extends vtkWidgetRepresentation
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetCheckerboard_2(vtkImageCheckerboard id0);
  public void SetCheckerboard(vtkImageCheckerboard id0)
    { SetCheckerboard_2(id0); }

  private native long GetCheckerboard_3();
  public vtkImageCheckerboard GetCheckerboard() {
    long temp = GetCheckerboard_3();

    if (temp == 0) return null;
    return (vtkImageCheckerboard)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetImageActor_4(vtkImageActor id0);
  public void SetImageActor(vtkImageActor id0)
    { SetImageActor_4(id0); }

  private native long GetImageActor_5();
  public vtkImageActor GetImageActor() {
    long temp = GetImageActor_5();

    if (temp == 0) return null;
    return (vtkImageActor)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetCornerOffset_6(double id0);
  public void SetCornerOffset(double id0)
    { SetCornerOffset_6(id0); }

  private native double GetCornerOffsetMinValue_7();
  public double GetCornerOffsetMinValue()
    { return GetCornerOffsetMinValue_7(); }

  private native double GetCornerOffsetMaxValue_8();
  public double GetCornerOffsetMaxValue()
    { return GetCornerOffsetMaxValue_8(); }

  private native double GetCornerOffset_9();
  public double GetCornerOffset()
    { return GetCornerOffset_9(); }

  private native void SliderValueChanged_10(int id0);
  public void SliderValueChanged(int id0)
    { SliderValueChanged_10(id0); }

  private native void SetTopRepresentation_11(vtkSliderRepresentation3D id0);
  public void SetTopRepresentation(vtkSliderRepresentation3D id0)
    { SetTopRepresentation_11(id0); }

  private native void SetRightRepresentation_12(vtkSliderRepresentation3D id0);
  public void SetRightRepresentation(vtkSliderRepresentation3D id0)
    { SetRightRepresentation_12(id0); }

  private native void SetBottomRepresentation_13(vtkSliderRepresentation3D id0);
  public void SetBottomRepresentation(vtkSliderRepresentation3D id0)
    { SetBottomRepresentation_13(id0); }

  private native void SetLeftRepresentation_14(vtkSliderRepresentation3D id0);
  public void SetLeftRepresentation(vtkSliderRepresentation3D id0)
    { SetLeftRepresentation_14(id0); }

  private native long GetTopRepresentation_15();
  public vtkSliderRepresentation3D GetTopRepresentation() {
    long temp = GetTopRepresentation_15();

    if (temp == 0) return null;
    return (vtkSliderRepresentation3D)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetRightRepresentation_16();
  public vtkSliderRepresentation3D GetRightRepresentation() {
    long temp = GetRightRepresentation_16();

    if (temp == 0) return null;
    return (vtkSliderRepresentation3D)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetBottomRepresentation_17();
  public vtkSliderRepresentation3D GetBottomRepresentation() {
    long temp = GetBottomRepresentation_17();

    if (temp == 0) return null;
    return (vtkSliderRepresentation3D)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetLeftRepresentation_18();
  public vtkSliderRepresentation3D GetLeftRepresentation() {
    long temp = GetLeftRepresentation_18();

    if (temp == 0) return null;
    return (vtkSliderRepresentation3D)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void BuildRepresentation_19();
  public void BuildRepresentation()
    { BuildRepresentation_19(); }

  private native void GetActors_20(vtkPropCollection id0);
  public void GetActors(vtkPropCollection id0)
    { GetActors_20(id0); }

  private native void ReleaseGraphicsResources_21(vtkWindow id0);
  public void ReleaseGraphicsResources(vtkWindow id0)
    { ReleaseGraphicsResources_21(id0); }

  private native int RenderOverlay_22(vtkViewport id0);
  public int RenderOverlay(vtkViewport id0)
    { return RenderOverlay_22(id0); }

  private native int RenderOpaqueGeometry_23(vtkViewport id0);
  public int RenderOpaqueGeometry(vtkViewport id0)
    { return RenderOpaqueGeometry_23(id0); }

  private native int RenderTranslucentPolygonalGeometry_24(vtkViewport id0);
  public int RenderTranslucentPolygonalGeometry(vtkViewport id0)
    { return RenderTranslucentPolygonalGeometry_24(id0); }

  private native int HasTranslucentPolygonalGeometry_25();
  public int HasTranslucentPolygonalGeometry()
    { return HasTranslucentPolygonalGeometry_25(); }

  public vtkCheckerboardRepresentation() { super(); }

  public vtkCheckerboardRepresentation(long id) { super(id); }
  public native long   VTKInit();

}
